# Supplementary Material 1
# Creating Figure 1

library(ggplot2)
library(rgdal)
library(maptools)

dat <- map_data("world")

## --- from http://www.naturalearthdata.com/downloads/10m-physical-vectors/
srange <- readShapePoly("gis/ne_10m_lakes") 

## --- Only the largest lakes
srange <- srange[srange$scalerank==0,]

jpeg(file="map_of_eradications.jpeg", width=190, height=110, units="mm",res=600)
ggplot()+
  geom_polygon(data=dat, aes(x=long,y=lat,group=group), fill="grey", col="white")+
  geom_polygon(data=srange, aes(x=long, y=lat, group=group), fill="white", col="white")+
  scale_x_continuous(breaks=c(-100,0,100))+
  xlab("Longitude")+
  ylab("Latitude")+
  theme(axis.text.x = element_text(size = 10, color = "black", 
                                   vjust=0.3), 
        axis.text.y = element_text(size = 12, color = "black"), 
        plot.background = element_blank(), 
        panel.border = element_blank(), 
        panel.grid.major = element_line(colour = NA), 
        panel.grid.minor = element_line(colour = NA), 
        panel.background = element_rect(fill = "white"), 
        axis.line.x = element_line(colour = "black"), 
        axis.line.y = element_line(colour = "black"))+
  # Hawaii
  annotate("rect", xmin = -160, xmax = -120, ymin = 30, ymax = 50, fill="white", col="black") +
  annotate("text", x=-140, y=40, label="USA (Hawaii) \n1 Eradication", size=2)+
  annotate("segment", x=-155, xend=-160, y=19, yend=30, color="black")+
  # French Polynesia
  annotate("rect", xmin = -165, xmax = -115, ymin = 10, ymax = -10, fill="white", col="black") + 
  annotate("text", x=-140, y=0, label="French Polynesia \n3 Eradications", size=2)+
  annotate("segment", x=-149, xend=-160, y=-17, yend=-10, color="black")+
  # Pictaim
  annotate("rect", xmin = -140, xmax = -100, ymin = -30, ymax = -50, fill="white", col="black") + 
  annotate("text", x=-120, y=-40, label="Pictaim \n2 Eradications", size=2)+
  annotate("segment", x=-128, xend=-140, y=-24, yend=-30, color="black")+
  # Turks and Caicos
  annotate("rect", xmin = -85, xmax = -35, ymin = 30, ymax = 50, fill="white", col="black") + 
  annotate("text", x=-60, y=40, label="Turks and Caicos \n1 Eradication", size=2)+
  annotate("segment", x=-71, xend=-40, y=21, yend=30, color="black")+
  # New Zealand
  annotate("rect", xmin = 110, xmax = 150, ymin = -50, ymax = -70, fill="white", col="black") + 
  annotate("text", x=130, y=-60, label="New Zealand \n56 Eradications", size=2)+
  annotate("segment", x=174, xend=110, y=-40, yend=-50, color="black")+
  # Australia
  annotate("rect", xmin =60  , xmax = 100, ymin = -40, ymax = -60, fill="white", col="black") + 
  annotate("text", x=80, y=-50, label="Australia \n5 Eradications", size=2)+
  annotate("segment", x=133, xend=60, y=-25, yend=-40, color="black")+
  # Mayoette
  annotate("rect", xmin = 10, xmax = 50, ymin = -40, ymax = -60, fill="white", col="black") + 
  annotate("text", x=30, y=-50, label="Mayoette \n2 Eradications", size=2)+
  annotate("segment", x=45, xend=10, y=-12, yend=-40, color="black")+
  # Seyechelles
  annotate("rect", xmin = 60, xmax = 100, ymin = -30, ymax = -10, fill="white", col="black") + 
  annotate("text", x=80, y=-20, label="Sayechelles \n8 Eradications", size=2)+
  annotate("segment", x=55, xend=60, y=-4, yend=-10, color="black")+
  # Italy
  annotate("rect", xmin = 30, xmax = 70, ymin = 30, ymax = 50, fill="white", col="black") + 
  annotate("text", x=50, y=40, label="Italy \n1 Eradication", size=2)+
  annotate("segment", x=12, xend=30, y=43, yend=30, color="black")+
  # Tunisa
  annotate("rect", xmin = 30, xmax = 70, ymin = 0, ymax = 20, fill="white", col="black") + 
  annotate("text", x=50, y=10, label="Tunisa \n1 Eradication", size=2)+
  annotate("segment", x=9, xend=30, y=33, yend=20, color="black")+
  # Spain
  annotate("rect", xmin = -40, xmax = 0, ymin = 0, ymax = 20, fill="white", col="black") + 
  annotate("text", x=-20, y=10, label="Spain \n7 Eradications", size=2)+
  annotate("segment", x=-2, xend=0, y=40, yend=20, color="black")+
  # UK
  annotate("rect", xmin = -40, xmax = 0, ymin = 60, ymax = 80,fill="white", col="black") + 
  annotate("text", x=-20, y=70, label="UK \n4 Eradications", size=2)+
  annotate("segment", x=-4, xend=0, y=55, yend=60, color="black")+
  # Japan
  annotate("rect", xmin = 160, xmax = 200, ymin = 40, ymax = 60,fill="white", col="black") + 
  annotate("text", x=180, y=50, label="Japan \n6 Eradications", size=2)+
  annotate("segment", x=138, xend=160, y=36, yend=40, color="black")+
  # Micronesia
  annotate("rect", xmin = 90, xmax = 130, ymin =10 , ymax = 30,fill="white", col="black") + 
  annotate("text", x=110, y=20, label="Micronesia \n3 Eradications", size=2)+
  annotate("segment", x=150, xend=130, y=7, yend=10, color="black")+
  # Tonga
  annotate("rect", xmin = 140, xmax = 180, ymin = 10, ymax = 30,fill="white", col="black") + 
  annotate("text", x=160, y=20, label="Tonga \n4 Eradications", size=2)+
  annotate("segment", x=185, xend=160, y=-21, yend=10, color="black")+
  # New Caledonia
  annotate("rect", xmin = 110, xmax = 150, ymin = -20, ymax = 0,fill="white", col="black") + 
  annotate("text", x=130, y=-10, label="New Caledonia \n2 Eradications", size=2)+
  annotate("segment", x=160, xend=150, y=-20, yend=-20, color="black")+
  # Fiji
  annotate("rect", xmin = 160, xmax = 200, ymin = -50, ymax = -70,fill="white", col="black") + 
  annotate("text", x=180, y=-60, label="Fiji \n4 Eradications", size=2)+
  annotate("segment", x=178, xend=200, y=-17, yend=-50, color="black")+
  # Samoa
  annotate("rect", xmin = 182, xmax = 222, ymin = -10, ymax = 10,fill="white", col="black") + 
  annotate("text", x=202, y=0, label="Samoa \n4 Eradications", size=2)+
  annotate("segment", x=187, xend=182, y=-13, yend=-10, color="black")
dev.off()  