# Supplementary Material 2
# Method Analysis and Figure

library(tidyverse)
library(RColorBrewer)
library(MASS)

dat <- read.csv("rail_data.csv", stringsAsFactors = FALSE) %>%
  mutate(mortality_2_factor = factor(Mortality1.0, levels=c(0,1)),
         logarea = log(Area.sqkm.))


nbmodel <- glm.nb(Mortality1.0 ~ Area.sqkm. + EradicationEndDate , data=dat)

model <- glm(Mortality1.0 ~ logarea + EradicationEndDate , data=dat, family=binomial(link="logit"))

summary(model)

dat$predicted <- predict(model, newdata=dat)

# graphdat <- dat %>% 
#               dplyr::select(logarea, EradicationEndDate,
#                      predicted, Mortality1.0) %>%
#               gather("variable","value",-predicted, -Mortality1.0) %>%
#               mutate(variable = case_when(variable == "Area.sqkm." ~ "Island Area (km)",
#                                           variable == "logarea" ~ "Log Island Area (km)",
#                                           variable == "EradicationEndDate" ~"Year"))

colorvals <- c("#762a83","#1b7837")

# a <- ggplot(data=graphdat, aes(x=value, 
#                         y=Mortality1.0))+
#         geom_point()+
#         geom_smooth(method="glm", method.args=list(family="binomial"),
#                     aes(color=variable))+
#         facet_wrap(~variable, scales = "free_x")+
#   scale_color_manual(values=colorvals)+
#   ylab("Probability of Reporting")+
#   theme(legend.title = element_blank(),
#         legend.position = "none",
#         axis.text.x = element_text(size = 8, color = "black", 
#                                    vjust=0.3), 
#         axis.text.y = element_text(size = 8, color = "black"), 
#         #axis.title.y = element_blank(),
#         axis.title.x = element_blank(),
#         plot.background = element_blank(), 
#         panel.border = element_blank(), 
#         panel.grid.major = element_line(colour = NA), 
#         panel.grid.minor = element_line(colour = NA), 
#         title = element_text(size = 20), 
#         panel.background = element_rect(fill = "white"), 
#         axis.line.x = element_line(colour = "black"), 
#         axis.line.y = element_line(colour = "black"),
#         strip.background = element_rect(fill = "white", 
#                                         color = "black"), 
#         strip.text = element_text(size = 10))
# 
# ggsave(a, file="figure2.jpeg", width=10, height=5, units="cm", dpi=300)



b <- ggplot(data=dat, aes(x=logarea, 
                               y=Mortality1.0))+
  geom_point()+
  geom_smooth(method="glm", method.args=list(family="binomial"),
              color=colorvals[1])+
  ylab("Probability of Reporting")+
  xlab("Log Area (km)")+
  theme(legend.title = element_blank(),
        legend.position = "none",
        axis.text.x = element_text(size = 8, color = "black", 
                                   vjust=0.3), 
        axis.text.y = element_text(size = 8, color = "black"), 
        axis.title.y = element_text(size=10),
        axis.title.x = element_text(size=10),
        plot.background = element_blank(), 
        panel.border = element_blank(), 
        panel.grid.major = element_line(colour = NA), 
        panel.grid.minor = element_line(colour = NA), 
        title = element_text(size = 20), 
        panel.background = element_rect(fill = "white"), 
        axis.line.x = element_line(colour = "black"), 
        axis.line.y = element_line(colour = "black"),
        strip.background = element_rect(fill = "white", 
                                        color = "black"), 
        strip.text = element_text(size = 10))


c <- ggplot(data=dat, aes(x=EradicationEndDate, 
                          y=Mortality1.0))+
  geom_point()+
  geom_smooth(method="glm", method.args=list(family="binomial"),
              color=colorvals[2])+
  ylab("Probability of Reporting")+
  xlab("Year")+
  theme(legend.title = element_blank(),
        legend.position = "none",
        axis.text.x = element_text(size = 8, color = "black", 
                                   vjust=0.3), 
        axis.text.y = element_blank(), 
        axis.title.y = element_blank(),
        axis.ticks.y=element_blank(),
        axis.title.x = element_text(size=10),
        plot.background = element_blank(), 
        panel.border = element_blank(), 
        panel.grid.major = element_line(colour = NA), 
        panel.grid.minor = element_line(colour = NA), 
        title = element_text(size = 20), 
        panel.background = element_rect(fill = "white"), 
        axis.line.x = element_line(colour = "black"), 
        axis.line.y = element_line(colour = "black"),
        strip.background = element_rect(fill = "white", 
                                        color = "black"), 
        strip.text = element_text(size = 10))

d <- cowplot::plot_grid(b, c, nrow=1)


ggsave(d, file="figure2.jpeg", width=10, height=5, units="cm", dpi=300)

ggsave(d, file="figure2.tiff", width=10, height=5, units="cm", dpi=300)
